@@ -34,12 +34,12 @@
 #include <tqmap.h>
 
 // KDE includes
-#include <klocale.h>
+#include <tdelocale.h>
 #include <klineedit.h>
 #include <knuminput.h>
 #include <kcombobox.h>
 #include <kuser.h>
-#include <klistview.h>
+#include <tdelistview.h>
 #include <kpushbutton.h>
 
 // System includes
@@ -48,10 +48,10 @@
 
 // application specific includes
 #include "smb4ksambaoptions.h"
-#include "../core/smb4kglobal.h"
+#include "../core/smb4tdeglobal.h"
 #include "../core/smb4ksettings.h"
 
-using namespace Smb4KGlobal;
+using namespace Smb4TDEGlobal;
 
 
 Smb4KSambaOptions::Smb4KSambaOptions( TQWidget *parent, const char *name )
@@ -374,10 +374,10 @@ Smb4KSambaOptions::Smb4KSambaOptions( TQWidget *parent, const char *name )
 
   // FIXME: Set "What's this' texts!!!
 
-  KListView *custom_options =   new KListView( custom_tab, "CustomOptionsList" );
+  TDEListView *custom_options =   new TDEListView( custom_tab, "CustomOptionsList" );
 //   custom_options->setAllColumnsShowFocus( true );
   custom_options->setSelectionMode( TQListView::Single );
-  custom_options->setVScrollBarMode( KListView::Auto );
+  custom_options->setVScrollBarMode( TDEListView::Auto );
   custom_options->addColumn( i18n( "Item" ), -1 );
   custom_options->addColumn( i18n( "Protocol" ), -1 );
 #ifndef __FreeBSD__
@@ -448,7 +448,7 @@ Smb4KSambaOptions::Smb4KSambaOptions( TQWidget *parent, const char *name )
   custom_rm_layout->setSpacing( 5 );
 
   KPushButton *remove_custom =  new KPushButton( KGuiItem( i18n( "Remove" ), "remove" ), custom_rm, "CustomRemoveItem" );
-  KPushButton *rm_all_custom =  new KPushButton( KGuiItem( i18n( "Remove All" ), "editdelete" ), custom_rm, "CustomRemoveAllItems" );
+  KPushButton *rm_all_custom =  new KPushButton( KGuiItem( i18n( "Remove All" ), "edit-delete" ), custom_rm, "CustomRemoveAllItems" );
 
   TQSpacerItem *spacer6 =        new TQSpacerItem( 0, 0, TQSizePolicy::Expanding, TQSizePolicy::Preferred );
 
@@ -882,7 +882,7 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
   else
   {
     // Get the list view:
-    KListView *view = static_cast<KListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "KListView", true )) );
+    TDEListView *view = static_cast<TDEListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "TDEListView", true )) );
 
     if ( view )
     {
@@ -1015,7 +1015,7 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
 
 void Smb4KSambaOptions::slotCustomProtocolChanged( int index )
 {
-  KListView *view =            static_cast<KListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "KListView", true )) );
+  TDEListView *view =            static_cast<TDEListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "TDEListView", true )) );
   KComboBox *custom_protocol = static_cast<KComboBox *>( TQT_TQWIDGET(child( "CustomProtocol", "KComboBox", true )) );
 
   if ( view && view->selectedItem() && custom_protocol )
@@ -1043,7 +1043,7 @@ void Smb4KSambaOptions::slotCustomProtocolChanged( int index )
 #ifndef __FreeBSD__
 void Smb4KSambaOptions::slotCustomFileSystemChanged( int index )
 {
-  KListView *view =              static_cast<KListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "KListView", true )) );
+  TDEListView *view =              static_cast<TDEListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "TDEListView", true )) );
   KComboBox *custom_filesystem = static_cast<KComboBox *>( TQT_TQWIDGET(child( "CustomFileSystem", "KComboBox", true )) );
 
   if ( view && view->selectedItem() && custom_filesystem )
@@ -1075,7 +1075,7 @@ void Smb4KSambaOptions::slotCustomFileSystemChanged( int )
 #ifndef __FreeBSD__
 void Smb4KSambaOptions::slotCustomWriteAccessChanged( int index )
 {
-  KListView *view =      static_cast<KListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "KListView", true )) );
+  TDEListView *view =      static_cast<TDEListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "TDEListView", true )) );
   KComboBox *custom_rw = static_cast<KComboBox *>( TQT_TQWIDGET(child( "CustomWriteAccess", "KComboBox", true )) );
 
   if ( view && view->selectedItem() && custom_rw )
@@ -1109,7 +1109,7 @@ void Smb4KSambaOptions::slotCustomKerberosChanged( int index )
   // FIXME: Do we need to adjust something here with respect to
   // FreeBSD? It does not know Kerberos for mounting!
 
-  KListView *view =            static_cast<KListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "KListView", true )) );
+  TDEListView *view =            static_cast<TDEListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "TDEListView", true )) );
   KComboBox *custom_kerberos = static_cast<KComboBox *>( TQT_TQWIDGET(child( "CustomWriteAccess", "KComboBox", true )) );
 
   if ( view && view->selectedItem() && custom_kerberos )
@@ -1136,7 +1136,7 @@ void Smb4KSambaOptions::slotCustomKerberosChanged( int index )
 
 void Smb4KSambaOptions::slotCustomUIDChanged( const TQString &uid )
 {
-  KListView *view = static_cast<KListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "KListView", true )) );
+  TDEListView *view = static_cast<TDEListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "TDEListView", true )) );
 
   if ( view && view->selectedItem() )
   {
@@ -1154,7 +1154,7 @@ void Smb4KSambaOptions::slotCustomUIDChanged( const TQString &uid )
 
 void Smb4KSambaOptions::slotCustomGIDChanged( const TQString &gid )
 {
-  KListView *view = static_cast<KListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "KListView", true )) );
+  TDEListView *view = static_cast<TDEListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "TDEListView", true )) );
 
   if ( view && view->selectedItem() )
   {
@@ -1172,7 +1172,7 @@ void Smb4KSambaOptions::slotCustomGIDChanged( const TQString &gid )
 
 void Smb4KSambaOptions::slotCustomPortChanged( int port )
 {
-  KListView *view = static_cast<KListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "KListView", true )) );
+  TDEListView *view = static_cast<TDEListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "TDEListView", true )) );
 
   if ( view && view->selectedItem() )
   {
@@ -1189,7 +1189,7 @@ void Smb4KSambaOptions::slotCustomPortChanged( int port )
 
 void Smb4KSambaOptions::slotRemoveCustomOption()
 {
-  KListView *view = static_cast<KListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "KListView", true )) );
+  TDEListView *view = static_cast<TDEListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "TDEListView", true )) );
 
   if ( view && view->selectedItem() )
   {
@@ -1208,7 +1208,7 @@ void Smb4KSambaOptions::slotRemoveCustomOption()
 
 void Smb4KSambaOptions::slotRemoveAllCustomOptions()
 {
-  KListView *view = static_cast<KListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "KListView", true )) );
+  TDEListView *view = static_cast<TDEListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "TDEListView", true )) );
 
   if ( view )
   {
