@@ -55,7 +55,7 @@ class Smb4KPrintInfo;
 class Smb4KPrint : public TQObject
 {
   Q_OBJECT
-  TQ_OBJECT
+  
 
   public:
     /**
@@ -106,17 +106,17 @@ class Smb4KPrint : public TQObject
     /**
      * This slot receives output at stdout.
      */
-    void slotReceivedStdout( KProcess *, char *buf, int len );
+    void slotReceivedStdout( TDEProcess *, char *buf, int len );
 
     /**
      * This slot receives output at stderr.
      */
-    void slotReceivedStderr( KProcess *, char *buf, int len );
+    void slotReceivedStderr( TDEProcess *, char *buf, int len );
 
     /**
      * This slot is called when the process exited.
      */
-    void slotProcessExited( KProcess * );
+    void slotProcessExited( TDEProcess * );
 
     /**
      * This slot is invoked if the print process should be restarted
@@ -127,9 +127,9 @@ class Smb4KPrint : public TQObject
   private:
 
     /**
-     * The KProcess object.
+     * The TDEProcess object.
      */
-    KProcess *m_proc;
+    TDEProcess *m_proc;
 
     /**
      * The buffer
