@@ -787,11 +787,11 @@ void Smb4KSystemTray::slotSetupSharesMenu()
 
         // Define the actions that can be performed on a share from within
         // the system tray widget:
-        TDEAction *umount       = new TDEAction( i18n( "&Unmount" ), "drive-harddisk", TDEShortcut::null(), TQT_TQOBJECT(this),
+        TDEAction *umount       = new TDEAction( i18n( "&Unmount" ), "drive-harddisk-unmounted", TDEShortcut::null(), TQT_TQOBJECT(this),
                                 TQT_SLOT( slotUnmountShare() ), actionCollection(), "st_[unmount]_"+(*it)->canonicalPath() );
         umount->setGroup( "ShareActions" );
 #ifdef __linux__
-        TDEAction *force_umount = new TDEAction( i18n( "&Force Unmounting" ), "drive-harddisk", TDEShortcut::null(), TQT_TQOBJECT(this),
+        TDEAction *force_umount = new TDEAction( i18n( "&Force Unmounting" ), "drive-harddisk-unmounted", TDEShortcut::null(), TQT_TQOBJECT(this),
                                 TQT_SLOT( slotForceUnmountShare() ), actionCollection(), "st_[force]_"+(*it)->canonicalPath() );
         force_umount->setGroup( "ShareActions" );
         force_umount->setEnabled( Smb4KSettings::useForceUnmount() );
